@@ -19,7 +19,9 @@ from sklearn.metrics import (
 
 
 class ModelResults:
-    def most_similar_texts(self, X, num_topics, num_examples, text_column_name):
+    def most_similar_texts(
+        self, X, num_topics, num_examples, num_words, text_column_name
+    ):
         """
         Uses NMF clustering to create n topics based on adjusted word frequencies
 
@@ -27,6 +29,8 @@ class ModelResults:
         --------
         X: DataFrame
         num_topics: int
+        num_examples: int
+        num_words: int
         text_column_name: str
 
         Returns
@@ -79,7 +83,7 @@ class ModelResults:
         topic_words = {}
         sample_texts_lst = []
         for topic, comp in enumerate(model.components_):
-            word_idx = np.argsort(comp)[::-1][:num_examples]
+            word_idx = np.argsort(comp)[::-1][:num_words]
             topic_words[topic] = [vocab[i] for i in word_idx]
             sample_texts_lst.append(
                 list(
@@ -93,8 +97,8 @@ class ModelResults:
             columns=["topic_num", "top_words", "sample_texts"]
         )
 
-        topic_words_df["topic_num"] = topic_words.keys()
-        topic_words_df["top_words"] = topic_words.values()
+        topic_words_df["topic_num"] = [x for x in topic_words.keys()]
+        topic_words_df["top_words"] = [x for x in topic_words.values()]
         topic_words_df["sample_texts"] = sample_texts_lst
 
         print("Topics created with top words & example texts:")
@@ -102,7 +106,7 @@ class ModelResults:
 
         return topic_words_df, combined_df[[text_column_name, "top_topic_num"]]
 
-    def coefficents_summary(
+    def coefficients_summary(
         self, X, y, num_repetitions, num_coefficients, model_type, params={}
     ):
         """
@@ -295,7 +299,6 @@ class ModelResults:
             Fit model
         y_predicted: array
         """
-
         # Fitting the final model
         full_pipeline.fit(X_train, y_train)
 
@@ -312,19 +315,13 @@ class ModelResults:
             print(f"Final Model ROC AUC: {roc_auc}")
 
             crosstab = pd.crosstab(
-                y_test["converted"].values,
-                y_predicted,
-                rownames=["Actual"],
-                colnames=["Predicted"],
+                y_test, y_predicted, rownames=["Actual"], colnames=["Predicted"],
             )
             print(crosstab)
             sum_crosstab = crosstab.to_numpy().sum()
             print(
                 pd.crosstab(
-                    y_test["converted"].values,
-                    y_predicted,
-                    rownames=["Actual"],
-                    colnames=["Predicted"],
+                    y_test, y_predicted, rownames=["Actual"], colnames=["Predicted"],
                 ).apply(lambda r: round(r / sum_crosstab, 3))
             )
         else:
